@@ -126,7 +126,7 @@ impl<K: TokenKind> Lexer<K> {
 }
 
 /// A scanner is a stateful lexer, i.e. one that keeps track of its current position.
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct Scanner<'a, 'l, K: TokenKind> {
   source: &'a str,
   position: usize,
@@ -139,7 +139,7 @@ impl<'a, 'l, K: TokenKind> Scanner<'a, 'l, K> {
   where
     F: Fn(&Token<'a, K>) -> bool,
   {
-    let token = self.lexer.read_at(self.source, self.position);
+    let token = self.lexer.scan(self.source, self.position);
     if f(&token) {
       self.position = token.end;
       Ok(token)
@@ -160,7 +160,7 @@ impl<'a, 'l, K: TokenKind> Scanner<'a, 'l, K> {
 
   /// Returns the next token as Ok(token) if it matches the given kind,
   /// otherwise returns the next token as Err(token)
-  pub fn next_of_kind<S>(&mut self, kind: K) -> Result<Token<'a, K>, Token<'a, K>> {
+  pub fn next_of_kind(&mut self, kind: K) -> Result<Token<'a, K>, Token<'a, K>> {
     self.next_of_kinds(&[kind])
   }
 }
